@@ -95,7 +95,7 @@ class ViewGeneralMethods:
         """
         model_object = self.db.get_or_404(model, object_id)
         return prepare_json_response(f'{model.__name__} get successfully',
-                                     data=generic_get_serialize_data(schema, model_object))
+                                     data=generic_get_serialize_data(schema(), model_object))
 
     def generic_delete(self, model, object_id):
         """
